chainalysis.utils._utils - Data Solutions Python SDK 1.1.0 documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
Toggle table of contents sidebar

# Source code for chainalysis.utils._utils

    from chainalysis.utils import Stringify

    class Utils:
        """
        This class contains util/helper functions for users
        of the SDK.
        """

        def __init__(self):
            self.s = Stringify()

        @property
        def stringify(self) -> Stringify:
            """
            Call the stringify property to access the Stringify class.
            """
            return self.s